wagtail-readinglevel
====================

A lightweight Wagtail plugin to determine the reading level of of text
input into a rich text field.

!! This is an experimental build meant to test yet unreleased api features in Wagtail. !!

Installation
------------
```pip install wagtail-readinglevel```

Usage
-----

Once installed add 'wagtailreadinglevel' to your list of installed apps AFTER all wagtail app includes (e.g. wagtail.admin, wagtail.core etc). 
  
Once installed You will see the reading level calculation displayed in the toolbar of all rich text fields in your Wagtail admin area.

Early development
-----------------

This repository has just been created, so expect things to change a lot
and change fast. The end goal is to make it easy for content writers to
determine the reading level of any copy they input into a rich text
field in Wagtail. This helps with meeting the WCAG 2.0 readability
standards.

Contributing
------------

Contributing will be encouraged soon, we just need to get a few of the
core files and concepts in place first. Feel free to contact Chris
(chris@vix.digital) if you have any insights into this kind of thing
that you’d like to share, all of that kind of thing is much appreciated!